@@ -23,7 +23,6 @@
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 #include <string.h>
-#include <libsexy/sexy-tree-view.h>
 
 #include "preferences-page.h"
 #include "preferences-page-plugins.h"
@@ -48,7 +47,6 @@ extern GSList *enabled_plugins;	// Our list of loaded plugins.
 extern XChatGUI gui;
 
 static PreferencesPagePlugins *pageref;
-static GtkWidget* get_plugin_tooltip (SexyTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, PreferencesPagePlugins *page);
 
 enum
 {
@@ -58,6 +56,7 @@ enum
 	COL_FILENAME,
 	COL_LOADED,
 	COL_DISPLAY,
+ 	COL_TOOLTIP,
 	COL_PAGE
 };
 
@@ -78,7 +77,7 @@ fe_plugin_add (char *filename)
 
 	void *handle;
 	gpointer info_func;
-	char *name, *desc, *version, *display;
+	char *name, *desc, *version, *display, *tooltip;
 
 	handle = g_module_open (filename, 0);
 
@@ -101,11 +100,14 @@ fe_plugin_add (char *filename)
 		desc = _("unknown");
 	}
 
-	display = g_strdup_printf ("<b>%s</b>\n%s", name, desc);
+	display = g_markup_printf_escaped ("<b>%s</b>\n%s", name, desc);
+	tooltip = g_markup_escape_text (desc, -1);
 	gtk_list_store_set (pageref->plugin_store, &iter, COL_NAME, name, COL_VERSION, version,
 			    COL_DESC, desc, COL_FILENAME, filename, COL_DISPLAY, display,
+			    COL_TOOLTIP, tooltip,
 			    COL_PAGE, NULL, -1);
 	g_free (display);
+	g_free (tooltip);
 
 	if (handle != NULL) {
 		g_module_close (handle);
@@ -341,25 +343,6 @@ remove_page_if_exist (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 	return FALSE;
 }
 
-static GtkWidget*
-get_plugin_tooltip (SexyTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, PreferencesPagePlugins *page)
-{
-	GtkTreeIter iter;
-	GtkWidget *label;
-	gchar *text;
-
-	label = NULL;
-
-	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (page->plugin_store), &iter, path)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (page->plugin_store), &iter, COL_DESC, &text, -1);
-		label = gtk_label_new (text);
-		g_free (text);
-		gtk_widget_show_all (label);
-	}
-
-	return label;
-}
-
 PreferencesPagePlugins*
 preferences_page_plugins_new (gpointer prefs_dialog, GladeXML *xml)
 {
@@ -374,12 +357,9 @@ preferences_page_plugins_new (gpointer prefs_dialog, GladeXML *xml)
 	GW(plugins_remove);
 #undef GW
 
-	page->plugins_list = sexy_tree_view_new ();
 	scroll = glade_xml_get_widget (xml, "scrolledwindow19");
-	gtk_container_add (GTK_CONTAINER (scroll), page->plugins_list);
-
-	gtk_widget_show (page->plugins_list);
 
+        /* FIXME multi-head */
 	GtkIconTheme *theme = gtk_icon_theme_get_default ();
 	PREFERENCES_PAGE (page)->icon = gtk_icon_theme_load_icon (theme, "xchat-gnome-plugin", 16, 0, NULL);
 
@@ -387,9 +367,14 @@ preferences_page_plugins_new (gpointer prefs_dialog, GladeXML *xml)
 	gtk_list_store_set (p->page_store, &iter, 0, PREFERENCES_PAGE (page)->icon, 1, _("Scripts and Plugins"), 2, 5, -1);
 
 	/*                                          name,          version,       description,   file,          loaded*/
-	page->plugin_store = gtk_list_store_new (7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-	                                         G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (page->plugins_list), GTK_TREE_MODEL (page->plugin_store));
+	page->plugin_store = gtk_list_store_new (8, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+	                                         G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+
+	page->plugins_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (page->plugin_store));
+	gtk_container_add (GTK_CONTAINER (scroll), page->plugins_list);
+	gtk_widget_show (page->plugins_list);
+
+	gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (page->plugins_list), COL_TOOLTIP);
 
 	page->load_renderer = gtk_cell_renderer_toggle_new ();
 	page->text_renderer = gtk_cell_renderer_text_new ();
@@ -414,8 +399,6 @@ preferences_page_plugins_new (gpointer prefs_dialog, GladeXML *xml)
 	g_signal_connect (G_OBJECT (select),               "changed",       G_CALLBACK (selection_changed),     page);
 	g_signal_connect (G_OBJECT (page->plugins_list),   "row-activated", G_CALLBACK (row_activated),         page);
 
-	g_signal_connect (G_OBJECT (page->plugins_list),   "get-tooltip",   G_CALLBACK (get_plugin_tooltip),    page);
-
 	pageref = page;
 	return page;
 }
